/*  smplayer, GUI front-end for mplayer.
    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/


#ifndef MPLAYERWINDOW_H
#define MPLAYERWINDOW_H

#include <qwidget.h>
#include <qsize.h>
#include <qpoint.h>
#include "config.h"

class QWidget;
class QLabel;
class QKeyEvent;


class Screen : public QWidget 
{
	Q_OBJECT

public:
	Screen(QWidget* parent = 0, const char* name = 0, WFlags fl = 0);
	~Screen();

signals:
	// For FULLSCREEN_WITH_MAINWINDOW
	void mouseMoved(QPoint);

protected:
	virtual void mouseMoveEvent( QMouseEvent * e );

protected slots:
	virtual void checkMousePos();

private:
	QPoint cursor_pos, last_cursor_pos;
};


class MplayerWindow : public Screen
{
    Q_OBJECT

public:
    MplayerWindow( QWidget* parent = 0, const char* name = 0, WFlags fl = 0);
    ~MplayerWindow();
    
    virtual void showLogo( bool b);
    virtual Screen * mplayerLayer();
    virtual void setResolution( int w, int h);
    virtual void setAspect( double asp);
	virtual void setMonitorAspect(double asp);
    virtual void updateVideoWindow();

	virtual QSize sizeHint () const;
	virtual QSize minimumSizeHint() const;

protected:
    virtual void resizeEvent( QResizeEvent * e);
    virtual void mouseReleaseEvent( QMouseEvent * e);
	virtual void mouseDoubleClickEvent( QMouseEvent * e );
	virtual void keyPressEvent( QKeyEvent * e );
	virtual void wheelEvent( QWheelEvent * e );

protected slots:
	virtual void languageChange();
	virtual void changePolicy();

	// For FULLSCREEN_WITH_MAINWINDOW
	virtual void translatePos(QPoint p );

signals:
    void rightButtonReleased( QPoint p );
	void doubleClicked();
	void leftClicked();
	void keyPressed(QKeyEvent * e);
	void wheelUp();
	void wheelDown();

protected:
    int video_width, video_height;
    double aspect;
	double monitoraspect;

	Screen * mplayerlayer;
	QLabel * logo;
};


#endif

